@@ -43,7 +43,7 @@ def _gpx(fname):
     try:
         import gpxpy
     except ImportError:
-        exit("ph gpx needs pgxpy, pip install ph[gpx]")
+        exit("ph gpx needs gpxpy, pip install ph[gpx]")
 
     def from_trackpoint(tp=None):
         if tp is None:
@@ -758,7 +758,7 @@ def ewm(
 
 
 @register
-def expanding(min_periods=1, center=False, axis=0, how="sum", quantile=None):
+def expanding(min_periods=1, axis=0, how="sum", quantile=None):
     """Provide expanding transformations.
 
     A common alternative to rolling statistics is to use an expanding
@@ -775,26 +775,18 @@ def expanding(min_periods=1, center=False, axis=0, how="sum", quantile=None):
            cat a.csv | ph expanding 1 --how=sum   # above equivalent to this
            cat a.csv | ph expanding 2
            cat a.csv | ph expanding 5 --how=quantile --quantile=0.25
-           cat a.csv | ph expanding 3 --center=True
 
     """
 
     df = pipein()
 
-    if center in TRUTHY:
-        center = True
-    elif center in FALSY:
-        center = False
-    else:
-        exit("center must be True of False, not {}".format(center))
-
     if quantile is not None:
         if how != "quantile":
             exit("Use both or none of --how=quantile and --quantile=<float>")
     if how == "quantile" and quantile is None:
 
         exit("--how=quantile needs --quantile=<float>, e.g. --quantile=0.25")
-    expanding_ = df.expanding(min_periods=min_periods, center=center, axis=axis)
+    expanding_ = df.expanding(min_periods=min_periods, axis=axis)
     try:
         fn = getattr(expanding_, how)
     except AttributeError:
@@ -888,11 +880,18 @@ def plot(*args, **kwargs):
             kwargs[log_] = True
     fname = kwargs.get("savefig")
     dpi = kwargs.get("savefig-dpi")
+
     if fname:
         del kwargs["savefig"]
     if dpi:
         del kwargs["savefig-dpi"]
-    df.plot(**kwargs)
+
+    fig, ax = plt.subplots()
+    df.plot(**kwargs, ax=ax)
+
+    if index == "date":
+        fig.autofmt_xdate()
+
     if fname:
         plt.tight_layout()
         plt.savefig(fname, dpi=dpi)
